@@ -36,20 +36,6 @@ def intercept_publish(fn, *args, **kwargs):
     datas = [' ', ' ', 'MQ SESSION INFO: ' + text]
     UdpSession.send_packet(PacketTypeEnum.TX_MSG, ctx, datas)
 
-
-start_time = DateUtil.nowSystem()
-    ctx.start_time = start_time
-
-    try:
-        callback = fn( *args, **kwargs)
-        return callback
-    except Exception as e:
-        interceptor_step_error(e)
-    finally:
-        ctx.db_opening = False
-
-    return callback
-
 def instrument_pika(module):
     def wrapper(fn):
         @trace_handler(fn)
