@@ -4,21 +4,50 @@ from whatap.net.udp_session import UdpSession
 from whatap.trace.mod.application_wsgi import interceptor, trace_handler, \
     interceptor_error
 from whatap.trace.trace_context_manager import TraceContextManager
+from whatap.trace.trace_context import TraceContext
 from whatap.util.date_util import DateUtil
 from whatap.util.userid_util import UseridUtil as userid_util
+import whatap.util.throttle_util as throttle_util
 import time
 
-init_load_interval=  30
+def blocking_handler():
+    def handler(func):
+        from django.http import HttpResponse
+        def wrapper(*args, **kwargs):
+            if conf.throttle_enabled and args and len(args) > 2:
+                remote_ip = userid_util.getRemoteAddr(args)
+                req = args[1]
+                path = req['PATH_INFO']
+                if throttle_util.isblocking(remote_ip, path):
+                    if conf.reject_event_enabled:
+                        ctx = TraceContextManager.getLocalContext()
+                        if not ctx:
+                            ctx = TraceContext()
+
+                        throttle_util.sendrejectevent(ctx, path, remote_ip)
+                    if conf.throttle_blocked_forward:
+                        response = HttpResponse(status=302)
+                        response['Location'] = throttle_blocked_forward
+                        return response
+                    status = '403 Forbidden'
+                    start_response= args[2]
+                    start_response(status, [])
+                    response = HttpResponse(content=conf.throttle_blocked_message, status=403)
+                    return response
+            return func(*args, **kwargs)
+
+        return wrapper
+
+    return handler
+
 def instrument(module):
     def wrapper(fn):
         @trace_handler(fn, True)
+        @blocking_handler()
         def trace(*args, **kwargs):
-            now = time.time()
-            if now - conf.last_loaded > init_load_interval:
-                conf.init(False)
 
             callback = interceptor(fn, *args, **kwargs)
-            
+
             return callback
         
         return trace
@@ -26,6 +55,7 @@ def instrument(module):
     module.WSGIHandler.__call__ = wrapper(module.WSGIHandler.__call__)
 
 
+
 def instrument_handlers_base(module):
     def wrapper(fn):
         @trace_handler(fn)
@@ -57,7 +87,7 @@ def instrument_handlers_base(module):
                         ctx.elapsed = DateUtil.nowSystem() - start_time
                         UdpSession.send_packet(PacketTypeEnum.TX_MSG, ctx,
                                                datas)
-            
+
             return callback
         
         return trace
@@ -65,6 +95,7 @@ def instrument_handlers_base(module):
     if hasattr(module.BaseHandler, 'apply_response_fixes'):
         module.BaseHandler.apply_response_fixes = wrapper(
             module.BaseHandler.apply_response_fixes)
+
     def wrapper(fn):
         @trace_handler(fn)
         def trace(*args, **kwargs):
@@ -168,5 +199,5 @@ def instrument_handlers_static(module):
         return trace
 
     module.StaticFilesHandler.get_response = get_response_wrapper(
-        module.BaseHandler.get_response)
+        module.StaticFilesHandler.get_response)
 
