@@ -119,6 +119,19 @@ def end_interceptor(thread_id=None, ctx= None):
 
     UdpSession.send_packet(PacketTypeEnum.TX_END, ctx, datas)
 
+def parseServiceName(environ):
+    
+    return environ.get('PATH_INFO', '')
+
+def isIgnore(service_name):
+    if conf.trace_ignore_url_prefix and service_name.startswith(conf.trace_ignore_url_prefix):
+        return True
+
+    if conf.trace_ignore_url_set and service_name in conf.trace_ignore_url_set:
+        return True
+    
+    return False
+
 def interceptor(rn_environ, *args, **kwargs):
     if not isinstance(rn_environ, tuple):
         rn_environ = (rn_environ, args[1])
@@ -126,8 +139,8 @@ def interceptor(rn_environ, *args, **kwargs):
     
     ctx = TraceContext()
     ctx.host = environ.get('HTTP_HOST', '').split(':')[0]
-    ctx.service_name = environ.get('PATH_INFO', '')
-
+    ctx.service_name = parseServiceName(environ)
+    
     ctx.remoteIp = userid_util.getRemoteAddr(args)
 
     ctx.userAgentString = environ.get('HTTP_USER_AGENT', '')
@@ -161,6 +174,13 @@ def interceptor(rn_environ, *args, **kwargs):
     if caller_poid:
         ctx.mcaller_poid = caller_poid
 
+    try:
+        if isIgnore(ctx.service_name):
+            ctx.is_ignored = True
+            return  fn(*args, **kwargs)
+    except Exception as e:
+        pass
+
     start_interceptor(ctx)
     
     try:
@@ -205,7 +225,6 @@ def interceptor(rn_environ, *args, **kwargs):
 
 
 def interceptor_error(status_code, errors):
-    print('error', status_code, errors)
     ctx = TraceContextManager.getLocalContext()
     ctx.status = int(status_code / 100)
     if ctx.status >= 4 and not ctx.error:
